@@ -269,6 +269,20 @@ class Firestore(object):
         """Delete a github user stored in firestore."""
         return self.app.collection('github_users').document(str(github_id)).delete()
 
+    def get_github_users(self, fields=None):
+        """Return a list of users."""
+        query = self.app.collection('github_users')
+        if fields:
+            query = query.select(fields)
+        users = []
+        for item in query.stream():
+            users.append(item.to_dict())
+        return users
+
+    def get_github_users_dict(self, key='id', fields=None):
+        """Return a dict of users by user id."""
+        return self.get_dict(self.get_github_users(fields=fields), key)
+
     def get_stored_github_user(self, github_id):
         """Return the stored user for the given github user id."""
         return self.app.collection('github_users').document(str(github_id)).get().to_dict()
@@ -301,6 +315,11 @@ class Firestore(object):
             tokens.append(doc.to_dict())
         return tokens
 
+    def store_token(self, token):
+        """Add or update the stored token for a user."""
+        google_id = token['google_id']
+        return self.app.collection('tokens').document(google_id).set(token)
+
     #
     # users - google users with special privileges in the app
     #
